==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterClusterMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterClusterMatchBuilder extends EnvoyFilterClusterMatchFluentImpl<EnvoyFilterClusterMatchBuilder> implements VisitableBuilder<EnvoyFilterClusterMatch,EnvoyFilterClusterMatchBuilder>{
  public EnvoyFilterClusterMatchBuilder() {
    this(false);
  }
  public EnvoyFilterClusterMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterClusterMatch(), validationEnabled);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterClusterMatch(), validationEnabled);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,EnvoyFilterClusterMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,EnvoyFilterClusterMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withService(instance.getService());
      fluent.withSubset(instance.getSubset());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withPortNumber(instance.getPortNumber());
      this.withService(instance.getService());
      this.withSubset(instance.getSubset());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterClusterMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterClusterMatch build() {
    EnvoyFilterClusterMatch buildable = new EnvoyFilterClusterMatch(fluent.getName(),fluent.getPortNumber(),fluent.getService(),fluent.getSubset());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterClusterMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterClusterMatchBuilder extends EnvoyFilterClusterMatchFluent<EnvoyFilterClusterMatchBuilder> implements VisitableBuilder<EnvoyFilterClusterMatch,EnvoyFilterClusterMatchBuilder>{
  public EnvoyFilterClusterMatchBuilder() {
    this(false);
  }
  public EnvoyFilterClusterMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterClusterMatch(), validationEnabled);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterClusterMatch(), validationEnabled);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,EnvoyFilterClusterMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatchFluent<?> fluent,EnvoyFilterClusterMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterClusterMatch());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withService(instance.getService());
      fluent.withSubset(instance.getSubset());
      fluent.withName(instance.getName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withService(instance.getService());
      fluent.withSubset(instance.getSubset());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterClusterMatchBuilder(EnvoyFilterClusterMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterClusterMatch());

    if (instance != null) {
      this.withName(instance.getName());
      this.withPortNumber(instance.getPortNumber());
      this.withService(instance.getService());
      this.withSubset(instance.getSubset());
      this.withName(instance.getName());
      this.withPortNumber(instance.getPortNumber());
      this.withService(instance.getService());
      this.withSubset(instance.getSubset());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterClusterMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterClusterMatch build() {
    EnvoyFilterClusterMatch buildable = new EnvoyFilterClusterMatch(fluent.getName(),fluent.getPortNumber(),fluent.getService(),fluent.getSubset());
    return buildable;
  }
  
}
